#include <GL/glu.h>

#ifndef GLU_VERSION_1_0
#define GLU_VERSION_1_0 1
#endif

#ifdef GLU_VERSION_1_0
#ifndef GLU_VERSION_1_1
typedef GLUnurbs		GLUnurbsObj;
typedef GLUtriangulatorObj	GLUtriangulatorObj;
typedef GLUquadricObj		GLUquadricObjObj;
#endif
#endif

